==> zio-aws-globalaccelerator_2.13-5.17.130.3-sources.jar: zio/aws/globalaccelerator/model/DescribeCustomRoutingEndpointGroupResponse.scala <==
package zio.aws.globalaccelerator.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DescribeCustomRoutingEndpointGroupResponse(
    endpointGroup: Option[
      zio.aws.globalaccelerator.model.CustomRoutingEndpointGroup
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.globalaccelerator.model.DescribeCustomRoutingEndpointGroupResponse = {
    import DescribeCustomRoutingEndpointGroupResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.globalaccelerator.model.DescribeCustomRoutingEndpointGroupResponse
      .builder()
      .optionallyWith(endpointGroup.map(value => value.buildAwsValue()))(
        _.endpointGroup
      )
      .build()
  }
  def asReadOnly
      : zio.aws.globalaccelerator.model.DescribeCustomRoutingEndpointGroupResponse.ReadOnly =
    zio.aws.globalaccelerator.model.DescribeCustomRoutingEndpointGroupResponse
      .wrap(buildAwsValue())
}
object DescribeCustomRoutingEndpointGroupResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.globalaccelerator.model.DescribeCustomRoutingEndpointGroupResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.globalaccelerator.model.DescribeCustomRoutingEndpointGroupResponse =
      zio.aws.globalaccelerator.model
        .DescribeCustomRoutingEndpointGroupResponse(
          endpointGroup.map(value => value.asEditable)
        )
    def endpointGroup: Option[
      zio.aws.globalaccelerator.model.CustomRoutingEndpointGroup.ReadOnly
    ]
    def getEndpointGroup: ZIO[
      Any,
      AwsError,
      zio.aws.globalaccelerator.model.CustomRoutingEndpointGroup.ReadOnly
    ] = AwsError.unwrapOptionField("endpointGroup", endpointGroup)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.globalaccelerator.model.DescribeCustomRoutingEndpointGroupResponse
  ) extends zio.aws.globalaccelerator.model.DescribeCustomRoutingEndpointGroupResponse.ReadOnly {
    override val endpointGroup: Option[
      zio.aws.globalaccelerator.model.CustomRoutingEndpointGroup.ReadOnly
    ] = scala
      .Option(impl.endpointGroup())
      .map(value =>
        zio.aws.globalaccelerator.model.CustomRoutingEndpointGroup.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.globalaccelerator.model.DescribeCustomRoutingEndpointGroupResponse
  ): zio.aws.globalaccelerator.model.DescribeCustomRoutingEndpointGroupResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-globalaccelerator_2.13-5.17.194.1-sources.jar: zio/aws/globalaccelerator/model/DescribeCustomRoutingEndpointGroupResponse.scala <==
package zio.aws.globalaccelerator.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DescribeCustomRoutingEndpointGroupResponse(
    endpointGroup: Optional[
      zio.aws.globalaccelerator.model.CustomRoutingEndpointGroup
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.globalaccelerator.model.DescribeCustomRoutingEndpointGroupResponse = {
    import DescribeCustomRoutingEndpointGroupResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.globalaccelerator.model.DescribeCustomRoutingEndpointGroupResponse
      .builder()
      .optionallyWith(endpointGroup.map(value => value.buildAwsValue()))(
        _.endpointGroup
      )
      .build()
  }
  def asReadOnly
      : zio.aws.globalaccelerator.model.DescribeCustomRoutingEndpointGroupResponse.ReadOnly =
    zio.aws.globalaccelerator.model.DescribeCustomRoutingEndpointGroupResponse
      .wrap(buildAwsValue())
}
object DescribeCustomRoutingEndpointGroupResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.globalaccelerator.model.DescribeCustomRoutingEndpointGroupResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.globalaccelerator.model.DescribeCustomRoutingEndpointGroupResponse =
      zio.aws.globalaccelerator.model
        .DescribeCustomRoutingEndpointGroupResponse(
          endpointGroup.map(value => value.asEditable)
        )
    def endpointGroup: Optional[
      zio.aws.globalaccelerator.model.CustomRoutingEndpointGroup.ReadOnly
    ]
    def getEndpointGroup: ZIO[
      Any,
      AwsError,
      zio.aws.globalaccelerator.model.CustomRoutingEndpointGroup.ReadOnly
    ] = AwsError.unwrapOptionField("endpointGroup", endpointGroup)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.globalaccelerator.model.DescribeCustomRoutingEndpointGroupResponse
  ) extends zio.aws.globalaccelerator.model.DescribeCustomRoutingEndpointGroupResponse.ReadOnly {
    override val endpointGroup: Optional[
      zio.aws.globalaccelerator.model.CustomRoutingEndpointGroup.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.endpointGroup())
      .map(value =>
        zio.aws.globalaccelerator.model.CustomRoutingEndpointGroup.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.globalaccelerator.model.DescribeCustomRoutingEndpointGroupResponse
  ): zio.aws.globalaccelerator.model.DescribeCustomRoutingEndpointGroupResponse.ReadOnly =
    new Wrapper(impl)
}
